"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.supportsNotificationsPermissionRequest = exports.supportsNotifications = void 0;
const os = require("os");
/**
 * Whether or not the current system supports these notifications. As of today,
 * only macOS and Windows 10+ are supported.
 */
function supportsNotifications() {
    if (process.platform === 'darwin') {
        return true;
    }
    if (process.platform !== 'win32') {
        return false;
    }
    const versionComponents = os.release().split('.');
    const majorVersion = parseInt(versionComponents[0], 10);
    // Only Windows 10 and newer are supported
    return majorVersion >= 10;
}
exports.supportsNotifications = supportsNotifications;
/**
 * Whether or not the current system supports asking the user for permission to
 * display notifications. As of today, only macOS supports this.
 */
function supportsNotificationsPermissionRequest() {
    return process.platform === 'darwin';
}
exports.supportsNotificationsPermissionRequest = supportsNotificationsPermissionRequest;
//# sourceMappingURL=notification-support.js.map